@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 14:03:12
-@LastEditTime: 2023-01-12 15:17:18
+@LastEditTime: 2023-02-17 10:35:04
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -26,6 +26,13 @@ class ActInfoHandler(ClientBaseHandler):
         :return: 
         :last_editors: HuangJianYi
         """
+        ver_no = self.get_param("ver_no", "1")
+        if ver_no == "1":
+            self.v1()
+        else:
+            self.v2()
+
+    def v1(self):
         app_id = self.get_app_id()
         act_id = self.get_act_id()
         app_base_model = AppBaseModel(context=self)
@@ -49,6 +56,55 @@ class ActInfoHandler(ClientBaseHandler):
         act_info_dict = self.business_process_executed(act_info_dict, ref_params={})
         return self.response_json_success(act_info_dict)
 
+    def v2(self):
+        app_id = self.get_app_id()
+        act_id = self.get_act_id()
+        app_base_model = AppBaseModel(context=self)
+        act_base_model = ActBaseModel(context=self)
+        app_info_dict = app_base_model.get_app_info_dict(app_id, field="seller_id,store_id,store_name,store_icon,app_icon")
+        if not app_info_dict:
+            return self.response_json_error("error", "小程序不存在")
+        invoke_result_data = self.business_process_executing()
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        if not invoke_result_data.data:
+            invoke_result_data.data = {}
+        exclude_fields = invoke_result_data.data["exclude_fields"] if invoke_result_data.data.__contains__("exclude_fields") else "is_del,finish_menu_config_json,agreement_json,is_fictitious,task_asset_type_json,refund_count,is_finish,is_launch,brand_json,share_desc_json,rule_desc_json,release_date,sort_index,create_date,modify_date,i1,i2,i3,i4,i5,s1,s2,s3,s4,s5,d1,d2"
+        act_info_dict = act_base_model.get_act_info_dict(act_id, True, False)
+        if not act_info_dict or act_info_dict["is_del"] == 1:
+            return self.response_json_error("error", "活动不存在")
+
+        act_info_dict["seller_id"] = app_info_dict["seller_id"]
+        act_info_dict["store_id"] = app_info_dict["store_id"]
+        act_info_dict["store_name"] = app_info_dict["store_name"]
+        act_info_dict["store_icon"] = app_info_dict["store_icon"]
+        act_info_dict["app_icon"] = app_info_dict["app_icon"]
+
+        # 分享配置 {"taoword": "", "icon": "", "title": "", "desc": ""}
+        act_info_dict["shares"] = {}
+        act_info_dict["shares"]["default"] = {"taoword": "", "icon": "", "title": "", "desc": ""}
+        if act_info_dict.__contains__("share_desc_json") and act_info_dict["share_desc_json"] not in ['', '{}']:
+            share_desc = SevenHelper.json_loads(act_info_dict["share_desc_json"])
+            if share_desc.__contains__("default"):
+                act_info_dict["shares"] = share_desc
+            else:
+                act_info_dict["shares"]["default"] = share_desc
+        # 规则配置 [{"title":"购买规则","desc":"在此填写规则"}]
+        act_info_dict["rules"] = SevenHelper.json_loads(act_info_dict["rule_desc_json"]) if act_info_dict["rule_desc_json"] else []
+        # 用户协议或隐私条款配置 [{"title":"购买规则","explain":"在此填写规则"}]
+        act_info_dict["purchase_agreement"] = SevenHelper.json_loads(act_info_dict["agreement_json"]) if act_info_dict["agreement_json"] else []
+        #品牌配置
+        act_info_dict["brands"] = SevenHelper.json_loads(act_info_dict["brand_json"]) if act_info_dict["brand_json"] else {}
+        act_info_dict = self.business_process_executed(act_info_dict, ref_params={})
+        for item in exclude_fields.split(','):
+            try:
+                del act_info_dict[item]
+            except:
+                pass
+        return self.response_json_success(act_info_dict)
+
+
+
 
 class ActPrizeListHandler(ClientBaseHandler):
     """
@@ -122,11 +178,16 @@ class CmsInfoListHandler(ClientBaseHandler):
             return self.response_json_success({"data": []})
         if not invoke_result_data.data:
             invoke_result_data.data = {}
+        condition = invoke_result_data.data["condition"] if invoke_result_data.data.__contains__("condition") else None
+        params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else None
         order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "id desc"
         field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
         cms_base_model = CmsBaseModel(context=self)
         page_count_mode = SevenHelper.get_enum_key(PageCountMode, page_count_mode)
-        page_list = cms_base_model.get_cms_info_list(place_id=place_id, page_size=page_size, page_index=page_index, order_by=order_by, field=field, app_id=app_id, act_id=act_id, is_cache=True, page_count_mode=page_count_mode)
+        if condition and params:
+            page_list = cms_base_model.get_cms_info_list_v2(place_id=place_id, page_size=page_size, page_index=page_index, order_by=order_by, field=field, condition=condition, params=params, is_cache=True, page_count_mode=page_count_mode)
+        else:
+            page_list = cms_base_model.get_cms_info_list(place_id=place_id, page_size=page_size, page_index=page_index, order_by=order_by, field=field, app_id=app_id, act_id=act_id, is_cache=True, page_count_mode=page_count_mode)
         if page_count_mode == "total":
             total = page_list[1]
             page_list = self.business_process_executed(page_list[0], ref_params={})
