@@ -99,7 +99,7 @@ class AddWechatSubscribeHandler(ClientBaseHandler):
         template_id = self.get_param("template_id")
         open_id = self.get_param("open_id")
         push_base_model = PushBaseModel(context=self)
-        invoke_result_data = push_base_model.add_wechat_subscribe(config.get_value("app_id"), template_id, open_id)
+        invoke_result_data = push_base_model.add_wechat_subscribe(share_config.get_value("app_id"), template_id, open_id)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success()
