@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-17 11:19:05
-@LastEditTime: 2023-02-15 15:06:46
+@LastEditTime: 2023-02-21 14:51:15
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -321,7 +321,7 @@ class InviteNewUserHandler(ClientBaseHandler):
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         if is_receive_reward == True:
-            invoke_result_data = task_base_model.process_receive_reward(app_id=app_id, act_id=act_id, module_id=module_id, user_id=from_user_id, login_token='', task_id=0, task_sub_type='', handler_name=self.__class__.__name__, request_code=self.request_code, task_type=4, check_new_user=False, check_user_nick=False, continue_request_expire=0, is_stat=False, info_json=None, check_act_info_release=False, check_act_module_release=False)
+            invoke_result_data = task_base_model.process_receive_reward(app_id=app_id, act_id=act_id, module_id=module_id, user_id=from_user_id, login_token='', task_id=0, task_sub_type='', handler_name=self.__class__.__name__, request_code=self.request_code, task_type=4, check_new_user=False, check_user_nick=False, continue_request_expire=0, is_stat=True, info_json=None, check_act_info_release=False, check_act_module_release=False)
             if invoke_result_data.success == True:
                 return self.response_json_success(invoke_result_data.data)
         return self.response_json_success(0)
@@ -347,7 +347,6 @@ class InviteJoinMemberHandler(ClientBaseHandler):
         app_id = self.get_app_id()
         act_id = self.get_act_id()
         user_id = self.get_user_id()
-        mix_nick = self.get_param("mix_nick")
         module_id = self.get_param_int("module_id", 0)
         login_token = self.get_param("login_token")
         from_user_id = self.get_param_int("invite_user_id", 0)
@@ -361,11 +360,8 @@ class InviteJoinMemberHandler(ClientBaseHandler):
         continue_request_expire = invoke_result_data.data["continue_request_expire"] if invoke_result_data.data.__contains__("continue_request_expire") else 5
         close_invite_limit = invoke_result_data.data["close_invite_limit"] if invoke_result_data.data.__contains__("close_invite_limit") else False
         is_receive_reward = invoke_result_data.data["is_receive_reward"] if invoke_result_data.data.__contains__("is_receive_reward") else False  #是否直接领取奖励
-        app_key, app_secret = self.get_app_key_secret()
-        app_base_model = AppBaseModel(context=self)
-        app_info_dict = app_base_model.get_app_info_dict(app_id)
-        access_token = app_info_dict["access_token"] if app_info_dict else ""
-        invoke_result_data = task_base_model.process_invite_join_member(app_id, act_id, module_id, user_id, login_token, mix_nick, from_user_id, self.__class__.__name__, access_token, app_key, app_secret, check_user_nick, continue_request_expire, close_invite_limit)
+
+        invoke_result_data = task_base_model.process_invite_join_member(app_id, act_id, module_id, user_id, login_token, from_user_id, self.__class__.__name__, check_user_nick, continue_request_expire, close_invite_limit)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         ref_params = {}
@@ -373,7 +369,7 @@ class InviteJoinMemberHandler(ClientBaseHandler):
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         if is_receive_reward == True:
-            invoke_result_data = task_base_model.process_receive_reward(app_id=app_id, act_id=act_id, module_id=module_id, user_id=from_user_id, login_token='', task_id=0, task_sub_type='', handler_name=self.__class__.__name__, request_code=self.request_code, task_type=5, check_new_user=False, check_user_nick=False, continue_request_expire=0, is_stat=False, info_json=None, check_act_info_release=False, check_act_module_release=False)
+            invoke_result_data = task_base_model.process_receive_reward(app_id=app_id, act_id=act_id, module_id=module_id, user_id=from_user_id, login_token='', task_id=0, task_sub_type='', handler_name=self.__class__.__name__, request_code=self.request_code, task_type=5, check_new_user=False, check_user_nick=False, continue_request_expire=0, is_stat=True, info_json=None, check_act_info_release=False, check_act_module_release=False)
             if invoke_result_data.success == True:
                 return self.response_json_success(invoke_result_data.data)
         return self.response_json_success(0)
@@ -419,7 +415,7 @@ class CollectGoodsHandler(ClientBaseHandler):
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         if is_receive_reward == True:
-            invoke_result_data = task_base_model.process_receive_reward(app_id=app_id, act_id=act_id, module_id=module_id, user_id=user_id, login_token=login_token, task_id=0, task_sub_type='', handler_name=self.__class__.__name__, request_code=self.request_code, task_type=8, check_new_user=False, check_user_nick=False, continue_request_expire=0, is_stat=False, info_json=None, check_act_info_release=False, check_act_module_release=False)
+            invoke_result_data = task_base_model.process_receive_reward(app_id=app_id, act_id=act_id, module_id=module_id, user_id=user_id, login_token=login_token, task_id=0, task_sub_type='', handler_name=self.__class__.__name__, request_code=self.request_code, task_type=8, check_new_user=False, check_user_nick=False, continue_request_expire=0, is_stat=True, info_json=None, check_act_info_release=False, check_act_module_release=False)
             if invoke_result_data.success == True:
                 return self.response_json_success(invoke_result_data.data)
         return self.response_json_success(0)
@@ -466,7 +462,7 @@ class BrowseGoodsHandler(ClientBaseHandler):
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         if is_receive_reward == True:
-            invoke_result_data = task_base_model.process_receive_reward(app_id=app_id, act_id=act_id, module_id=module_id, user_id=user_id, login_token=login_token, task_id=0, task_sub_type='', handler_name=self.__class__.__name__, request_code=self.request_code, task_type=9, check_new_user=False, check_user_nick=False, continue_request_expire=0, is_stat=False, info_json=None, check_act_info_release=False, check_act_module_release=False)
+            invoke_result_data = task_base_model.process_receive_reward(app_id=app_id, act_id=act_id, module_id=module_id, user_id=user_id, login_token=login_token, task_id=0, task_sub_type='', handler_name=self.__class__.__name__, request_code=self.request_code, task_type=9, check_new_user=False, check_user_nick=False, continue_request_expire=0, is_stat=True, info_json=None, check_act_info_release=False, check_act_module_release=False)
             if invoke_result_data.success == True:
                 return self.response_json_success(invoke_result_data.data)
         return self.response_json_success(0)
@@ -532,7 +528,7 @@ class JoinMemberHandler(ClientBaseHandler):
         app_id = self.get_app_id()
         act_id = self.get_act_id()
         user_id = self.get_user_id()
-        module_id = int(self.get_param("module_id", 0))
+        module_id = self.get_param_int("module_id", 0)
         login_token = self.get_param("login_token")
         task_base_model = TaskBaseModel(context=self)
         invoke_result_data = self.business_process_executing()
@@ -544,11 +540,7 @@ class JoinMemberHandler(ClientBaseHandler):
         continue_request_expire = invoke_result_data.data["continue_request_expire"] if invoke_result_data.data.__contains__("continue_request_expire") else 5
         is_stat = invoke_result_data.data["is_stat"] if invoke_result_data.data.__contains__("is_stat") else True
         info_json = invoke_result_data.data["info_json"] if invoke_result_data.data.__contains__("info_json") else None
-        app_key, app_secret = self.get_app_key_secret()
-        app_base_model = AppBaseModel(context=self)
-        app_info_dict = app_base_model.get_app_info_dict(app_id)
-        access_token = app_info_dict["access_token"] if app_info_dict else ""
-        invoke_result_data = task_base_model.process_join_member(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, access_token, app_key, app_secret, self.request_code, check_user_nick, continue_request_expire, is_stat, info_json)
+        invoke_result_data = task_base_model.process_join_member(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, check_user_nick, continue_request_expire, is_stat, info_json)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         ref_params = {}
@@ -606,7 +598,7 @@ class BrowseSiteHandler(ClientBaseHandler):
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         if is_receive_reward == True:
-            invoke_result_data = task_base_model.process_receive_reward(app_id=app_id, act_id=act_id, module_id=module_id, user_id=user_id, login_token=login_token, task_id=0, task_sub_type=task_sub_type, handler_name=self.__class__.__name__, request_code=self.request_code, task_type=task_type, check_new_user=False, check_user_nick=False, continue_request_expire=0, is_stat=False, info_json=None, check_act_info_release=False, check_act_module_release=False)
+            invoke_result_data = task_base_model.process_receive_reward(app_id=app_id, act_id=act_id, module_id=module_id, user_id=user_id, login_token=login_token, task_id=0, task_sub_type=task_sub_type, handler_name=self.__class__.__name__, request_code=self.request_code, task_type=task_type, check_new_user=False, check_user_nick=False, continue_request_expire=0, is_stat=True, info_json=None, check_act_info_release=False, check_act_module_release=False)
             if invoke_result_data.success == True:
                 return self.response_json_success(invoke_result_data.data)
         return self.response_json_success(0)
@@ -652,7 +644,7 @@ class ShareHandler(ClientBaseHandler):
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         if is_receive_reward == True:
-            invoke_result_data = task_base_model.process_receive_reward(app_id=app_id, act_id=act_id, module_id=module_id, user_id=user_id, login_token=login_token, task_id=0, task_sub_type='', handler_name=self.__class__.__name__, request_code=self.request_code, task_type=14, check_new_user=False, check_user_nick=False, continue_request_expire=0, is_stat=False, info_json=None, check_act_info_release=False, check_act_module_release=False)
+            invoke_result_data = task_base_model.process_receive_reward(app_id=app_id, act_id=act_id, module_id=module_id, user_id=user_id, login_token=login_token, task_id=0, task_sub_type='', handler_name=self.__class__.__name__, request_code=self.request_code, task_type=14, check_new_user=False, check_user_nick=False, continue_request_expire=0, is_stat=True, info_json=None, check_act_info_release=False, check_act_module_release=False)
             if invoke_result_data.success == True:
                 return self.response_json_success(invoke_result_data.data)
         return self.response_json_success(0)
