@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2022-04-24 15:15:19
-@LastEditTime: 2023-02-10 09:42:22
+@LastEditTime: 2023-02-20 18:06:29
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -540,12 +540,16 @@ class FrameBaseHandler(BaseApiHandler):
         access_token = self.get_param("access_token")
         plat_type = share_config.get_value("plat_type", 1)  # 平台类型
         if plat_type == 1:
+            env = self.get_param("env") if self.get_param("env") else config.get_value("env","")
             test_config = share_config.get_value("test_config", {})
-            user_nick = self.get_param("user_nick")
-            if user_nick:
+            if self.get_param("source_app_id") == "": #使用场景：通过IDE工具进行测试
+                access_token = test_config.get("access_token","")
+            elif env and env != 'online':  #使用场景：通过千牛端在测试环境进行测试
+                user_nick = self.get_param("user_nick",'')
                 store_user_nick = user_nick.split(':')[0]
                 if store_user_nick and store_user_nick == test_config.get("user_nick",""):
                     access_token = test_config.get("access_token","")
+
         return access_token
 
     def get_act_id(self):
