@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 15:42:53
-@LastEditTime: 2023-02-13 18:17:44
+@LastEditTime: 2023-02-17 18:20:19
 @LastEditors: HuangJianYi
 @Description: 活动模块
 """
@@ -27,8 +27,11 @@ class ActTypeListHandler(ClientBaseHandler):
         app_id = self.get_app_id()
         is_act = int(self.get_param("is_act", 0))
         marketing_id = int(self.get_param("marketing_id", 0))
-        condition = "market_ids LIKE '%," + str(marketing_id) + ",%'" if marketing_id > 0 else ""
-        act_type_list = ActTypeModel(context=self).get_cache_list(where=condition)
+        condition_where = ConditionWhere()
+        if marketing_id > 0:
+            condition_where.add_condition("market_ids LIKE '%," + str(marketing_id) + ",%'")
+        condition_where.add_condition("is_release=1")
+        act_type_list = ActTypeModel(context=self).get_cache_list(where=condition_where.to_string())
         new_list = []
         for act_type in act_type_list:
             act_type.play_process_json = self.json_loads(act_type.play_process_json) if act_type.play_process_json else {}
