@@ -145,6 +145,8 @@ class PrizeRosterListHandler(ClientBaseHandler):
         :param user_code：用户标识
         :param user_open_id：open_id
         :param nick_name：用户昵称
+        :param module_name：模块名称
+        :param prize_name：奖品名称
         :param order_no：订单号
         :param goods_type：物品类型（1虚拟2实物）
         :param prize_type：奖品类型(1现货2优惠券3红包4参与奖5预售)
@@ -165,6 +167,8 @@ class PrizeRosterListHandler(ClientBaseHandler):
         user_open_id = self.get_param("user_open_id")
         order_no = self.get_param("order_no")
         user_nick = self.get_param("nick_name")
+        module_name = self.get_param("module_name")
+        prize_name = self.get_param("prize_name")
         goods_type = int(self.get_param("goods_type", -1))
         prize_type = int(self.get_param("prize_type", -1))
         logistics_status = int(self.get_param("logistics_status", -1))
@@ -184,8 +188,17 @@ class PrizeRosterListHandler(ClientBaseHandler):
         params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
         order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
         field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
+        condition_where = ConditionWhere()
+        condition_where.add_condition(condition)
+        if module_name:
+            condition_where.add_condition("module_name=%s")
+            params.append(module_name)
+        if prize_name:
+            condition_where.add_condition("prize_name=%s")
+            params.append(prize_name)
+
         order_base_model = OrderBaseModel(context=self)
-        page_list, total= order_base_model.get_prize_roster_list(app_id, act_id, module_id, user_id, user_open_id, user_nick, order_no, goods_type, prize_type, logistics_status, prize_status, pay_status, page_size, page_index, create_date_start, create_date_end, order_by=order_by, field=field, condition=condition, params=params, is_cache=False)
+        page_list, total = order_base_model.get_prize_roster_list(app_id, act_id, module_id, user_id, user_open_id, user_nick, order_no, goods_type, prize_type, logistics_status, prize_status, pay_status, page_size, page_index, create_date_start, create_date_end, order_by=order_by, field=field, condition=condition_where.to_string(), params=params, is_cache=False)
         ref_params = {}
         page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list, ref_params=ref_params))
         return self.response_json_success(page_info)
@@ -396,6 +409,7 @@ class PrizeOrderExportHandler(ClientBaseHandler):
                     data_row["小程序订单号"] = prize_order_dict["order_no"]
                     data_row["淘宝子订单号"] = prize_roster_dict["sub_pay_order_no"]
                     data_row["淘宝名"] = prize_order_dict["user_nick"]
+                    data_row["openid"] = prize_order_dict["open_id"]
                     data_row["模块名称"] = prize_roster_dict["module_name"]
                     data_row["奖品名称"] = prize_roster_dict["prize_name"]
                     data_row["商家编码"] = prize_roster_dict["goods_code"]
@@ -508,6 +522,7 @@ class PrizeRosterExportHandler(ClientBaseHandler):
             data_row["小程序订单号"] = prize_roster_dict["order_no"]
             data_row["淘宝子订单号"] = prize_roster_dict["sub_pay_order_no"]
             data_row["淘宝名"] = prize_roster_dict["user_nick"]
+            data_row["openid"] = prize_roster_dict["open_id"]
             data_row["模块名称"] = prize_roster_dict["module_name"]
             data_row["奖品名称"] = prize_roster_dict["prize_name"]
             data_row["奖品价值"] = str(prize_roster_dict["prize_price"])
@@ -609,6 +624,7 @@ class TaoPayOrderExportHandler(ClientBaseHandler):
             data_row["淘宝主订单号"] = tao_pay_order_dict["main_pay_order_no"]
             data_row["淘宝子订单号"] = tao_pay_order_dict["sub_pay_order_no"]
             data_row["淘宝名"] = tao_pay_order_dict["user_nick"]
+            data_row["openid"] = tao_pay_order_dict["open_id"]
             data_row["商家编码"] = tao_pay_order_dict["goods_code"]
             data_row["商品名称"] = tao_pay_order_dict["goods_name"]
             data_row["购买数量"] = tao_pay_order_dict["buy_num"]
