@@ -365,7 +365,7 @@ class AssetBaseModel():
             condition+= " AND asset_type=%s"
             params.append(asset_type)
         if user_ids:
-            if ',' in str(user_ids):
+            if isinstance(user_ids,str):
                 condition += f" AND user_id in ({user_ids})"
             elif isinstance(user_ids,list):
                 condition+=" AND " + SevenHelper.get_condition_by_int_list("user_id",user_ids)
