@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-19 13:37:16
-@LastEditTime: 2023-02-06 15:35:29
+@LastEditTime: 2023-02-10 15:08:33
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -11,6 +11,7 @@ from seven_framework.console.base_console import *
 from seven_cloudapp_frame.models.seven_model import InvokeResultData
 from seven_cloudapp_frame.models.frame_base_model import *
 from seven_cloudapp_frame.libs.customize.seven_helper import *
+from seven_cloudapp_frame.libs.common import *
 from seven_cloudapp_frame.models.console_models.timing_work_model import *
 from seven_cloudapp_frame.models.db_models.stat.stat_queue_model import *
 from seven_cloudapp_frame.models.db_models.stat.stat_orm_model import *
@@ -30,10 +31,10 @@ class StatConsoleModel():
         :return: 
         :last_editors: HuangJianYi
         """
-        stat_config = config.get_value("stat_config", {})
+        stat_config = share_config.get_value("stat_config", {})
         is_process_stat = stat_config.get("is_process_stat", True)
         if is_process_stat:
-            stat_process_ways = config.get_value("stat_process_ways","mysql")
+            stat_process_ways = share_config.get_value("stat_process_ways", "redis")
             if stat_process_ways == "mysql":
                 for i in range(mod_count):
                     t = threading.Thread(target=self._process_stat_queue, args=[i, mod_count])
@@ -379,7 +380,7 @@ class StatUserDataWork(TimingWork):
         :last_editors: HuangJianYi
         """
         stat_log_model = StatUserLogModel()
-        stat_config = config.get_value("stat_config", {})
+        stat_config = share_config.get_value("stat_config", {})
         space_day = int(stat_config.get("user_log_space_day", 30))
         while True:
             is_del = stat_log_model.del_entity("create_day<%s", params=[SevenHelper.get_now_day_int(-24 * space_day)], limit="100")
@@ -393,7 +394,7 @@ class StatUserDataWork(TimingWork):
         :last_editors: HuangJianYi
         """
         stat_user_report_model = StatUserReportModel()
-        stat_config = config.get_value("stat_config",{})
+        stat_config = share_config.get_value("stat_config", {})
         space_day = int(stat_config.get("user_report_space_day", 365))
         while True:
             stat_user_report_list = stat_user_report_model.get_list(where="create_day<%s", order_by="id asc", limit="100", params=[SevenHelper.get_now_day_int(-24 * space_day)])
