@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 09:24:43
-@LastEditTime: 2023-02-15 15:36:55
+@LastEditTime: 2023-02-21 09:58:12
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -204,6 +204,8 @@ class OrderBaseModel(FrameBaseModel):
                 prize_roster_model.update_table("logistics_status=2", "act_id=%s and order_no=%s", [prize_order.act_id,prize_order.order_no])
             else:
                 prize_order_model.update_table("order_status=%s,modify_date=%s", "id=%s", [order_status, now_datetime, prize_order_id])
+                if order_status == 0:
+                    prize_roster_model.update_table("logistics_status=0", "act_id=%s and order_no=%s", [prize_order.act_id,prize_order.order_no])
             result,message = db_transaction.commit_transaction(True)
             if result == False:
                 raise Exception("执行事务失败",message)
@@ -506,6 +508,7 @@ class OrderBaseModel(FrameBaseModel):
             result,message = db_transaction.commit_transaction(True)
             if result == False:
                 raise Exception("执行事务失败",message)
+            prize_roster_model.delete_dependency_key([DependencyKey.prize_roster_list(act_id, user_id),DependencyKey.prize_order_list(act_id,user_id)])
         except Exception as ex:
             if self.context:
                 self.context.logging_link_error("create_prize_order:" + traceback.format_exc())
@@ -817,56 +820,57 @@ class OrderBaseModel(FrameBaseModel):
         :return:
         :last_editors: HuangJianYi
         """
-        where = "app_id=%s"
+        condition_where = ConditionWhere()
+        condition_where.add_condition( "app_id=%s")
         params_list = [app_id]
         if act_id >= 0:
-            where += " AND act_id=%s"
+            condition_where.add_condition( "act_id=%s")
             params_list.append(act_id)
         if condition:
-            where += " AND " + condition
+            condition_where.add_condition( "condition=%s")
             params_list.extend(params)
         if module_id:
-            where += " AND module_id=%s"
+            condition_where.add_condition( "module_id=%s")
             params_list.append(module_id)
         if user_id:
-            where += " AND user_id=%s"
+            condition_where.add_condition( "user_id=%s")
             params_list.append(user_id)
         if open_id:
-            where += " AND open_id=%s"
+            condition_where.add_condition( "open_id=%s")
             params_list.append(open_id)
         if user_nick:
-            where += " AND user_nick=%s"
+            condition_where.add_condition( "user_nick=%s")
             params_list.append(user_nick)
         if order_no:
-            where += " AND order_no=%s"
+            condition_where.add_condition( "order_no=%s")
             params_list.append(order_no)
         if goods_type !=-1:
-            where += " AND goods_type=%s"
+            condition_where.add_condition( "goods_type=%s")
             params_list.append(goods_type)
         if prize_type !=-1:
-            where += " AND prize_type=%s"
+            condition_where.add_condition( "prize_type=%s")
             params_list.append(prize_type)
         if logistics_status !=-1:
-            where += " AND logistics_status=%s"
+            condition_where.add_condition( "logistics_status=%s")
             params_list.append(logistics_status)
         if prize_status !=-1:
-            where += " AND prize_status=%s"
+            condition_where.add_condition( "prize_status=%s")
             params_list.append(prize_status)
         if pay_status !=-1:
-            where += " AND pay_status=%s"
+            condition_where.add_condition( "pay_status=%s")
             params_list.append(pay_status)
         if create_date_start:
-            where += " AND create_date>=%s"
+            condition_where.add_condition( "create_date>=%s")
             params_list.append(create_date_start)
         if create_date_end:
-            where += " AND create_date<=%s"
+            condition_where.add_condition( "create_date<=%s")
             params_list.append(create_date_end)
 
         prize_roster_model = PrizeRosterModel(sub_table=self.get_business_sub_table("prize_roster_tb",{"app_id":app_id}),context=self.context)
         if is_cache:
-            page_list = prize_roster_model.get_cache_dict_page_list(field, page_index, page_size, where, "", order_by, params_list, dependency_key=DependencyKey.prize_roster_list(act_id,user_id), page_count_mode=page_count_mode)
+            page_list = prize_roster_model.get_cache_dict_page_list(field, page_index, page_size, condition_where.to_string(), "", order_by, params_list, dependency_key=DependencyKey.prize_roster_list(act_id,user_id), page_count_mode=page_count_mode)
         else:
-            page_list = prize_roster_model.get_dict_page_list(field, page_index, page_size, where, "", order_by, params_list, page_count_mode)
+            page_list = prize_roster_model.get_dict_page_list(field, page_index, page_size, condition_where.to_string(), "", order_by, params_list, page_count_mode)
         return page_list
 
     def get_horseracelamp_list(self, app_id, act_id, module_id, is_search_module=False, condition="", params=[], page_size=30):
