@@ -2,11 +2,12 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 15:44:04
-@LastEditTime: 2022-01-21 21:30:04
+@LastEditTime: 2023-02-10 10:38:55
 @LastEditors: HuangJianYi
 @Description: 
 """
 from seven_cloudapp_frame.models.seven_model import *
+from seven_cloudapp_frame.libs.common import *
 from seven_cloudapp_frame.libs.customize.seven_helper import *
 from seven_cloudapp_frame.models.act_base_model import *
 from seven_cloudapp_frame.models.db_models.theme.theme_info_model import *
@@ -54,7 +55,7 @@ class ThemeBaseModel():
         skin_info_list = SkinInfoModel(context=self.context).get_dict_list("theme_id=%s", params=theme_id)
         theme_info_dict["skin_list"] = skin_info_list
         if is_cache:
-            redis_init.set(cache_key, SevenHelper.json_dumps(theme_info_dict), ex=config.get_value("cache_expire", 600))
+            redis_init.set(cache_key, SevenHelper.json_dumps(theme_info_dict), ex=share_config.get_value("cache_expire", 600))
         return theme_info_dict
 
     def get_theme_list(self,app_id,is_public=True,is_cache=True):
