@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-08-12 09:06:24
-@LastEditTime: 2023-02-09 19:35:23
+@LastEditTime: 2023-02-22 14:50:14
 @LastEditors: HuangJianYi
 :description: 淘宝top接口基础类
 """
@@ -54,7 +54,7 @@ class TopBaseModel():
         if app_id:
             app_info = app_info_model.get_entity(where="app_id=%s", params=app_id)
             if app_info:
-                invoke_result_data.data = {"app_id": app_info.app_id, "store_user_nick": app_info.store_user_nick, "user_nick": app_info.store_user_nick, "access_token": app_info.access_token}
+                invoke_result_data.data = {"app_id": app_info.app_id, "store_user_nick": app_info.store_user_nick, "user_nick": app_info.store_user_nick, "access_token": app_info.access_token, "seller_id":app_info.seller_id}
                 return invoke_result_data
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
@@ -94,7 +94,7 @@ class TopBaseModel():
                 app_info.access_token = access_token
             app_info_model.update_entity(app_info, "main_user_open_id,expiration_date,project_code,access_token")
             app_info_model.delete_dependency_key(DependencyKey.app_info(app_info.app_id))
-            invoke_result_data.data = {"app_id": app_info.app_id, "store_user_nick": app_info.store_user_nick, "user_nick": user_nick, "access_token": app_info.access_token,"is_change_project_code":is_change_project_code}
+            invoke_result_data.data = {"app_id": app_info.app_id, "store_user_nick": app_info.store_user_nick, "user_nick": user_nick, "access_token": app_info.access_token, "seller_id":app_info.seller_id, "is_change_project_code":is_change_project_code}
             return invoke_result_data
 
         # if ":" in user_nick:
@@ -178,7 +178,7 @@ class TopBaseModel():
             if "miniapp_template_onlineapp_response" in online_app_info.keys():
                 app_info.app_url = online_app_info["miniapp_template_onlineapp_response"]["app_info"]["online_url"]
             app_info.id = app_info_model.add_entity(app_info)
-            invoke_result_data.data = {"app_id": app_info.app_id, "store_user_nick": store_user_nick, "user_nick": user_nick, "access_token": access_token,"is_change_project_code":is_change_project_code}
+            invoke_result_data.data = {"app_id": app_info.app_id, "store_user_nick": store_user_nick, "user_nick": user_nick, "access_token": access_token, "seller_id":app_info.seller_id, "is_change_project_code":is_change_project_code}
             return invoke_result_data
         except Exception as ex:
             if self.context:
@@ -359,7 +359,7 @@ class TopBaseModel():
 
     def get_buy_order_list(self, open_id, access_token, app_key, app_secret, start_created="", end_created="", page_size=50, is_log=False, type="fixed,step",field="tid,status,payment,price,created,orders,num,pay_time,step_trade_status,step_paid_fee,type"):
         """
-        :description: 获取淘宝购买订单
+        :description: 获取淘宝购买订单，出现API字段映射错误，请提供参数信息联系小二处理。字段名:buyer_nick，说明open_id跟app_key没对应上，不是app_key下产品的open_id
         :param open_id：open_id
         :param access_token：access_token
         :param app_key:app_key
@@ -554,9 +554,9 @@ class TopBaseModel():
         """
         :description: 获取店铺信息
         :param access_token：access_token
-        :param is_log：是否记录返回信息
         :param app_key：app_key
         :param app_secret：app_secret
+        :param is_log：是否记录返回信息
         :return: InvokeResultData
         :last_editors: HuangJianYi
         """
