@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-22 11:10:20
-@LastEditTime: 2023-02-15 13:33:50
+@LastEditTime: 2023-02-21 09:11:19
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -191,7 +191,7 @@ class UserBaseModel(FrameBaseModel):
         user_info_model = UserInfoModel(sub_table=self.get_business_sub_table("user_info_tb",{"app_id":app_id}), context=self.context)
         now_datetime = SevenHelper.get_now_datetime()
         try:
-            user_account = user_account_model.get_entity("open_id=%s", params=[open_id])
+            user_account = user_account_model.get_cache_entity("open_id=%s", params=[open_id],dependency_key=DependencyKey.user_account(open_id))
             if not user_account:
                 user_account = UserAccount()
                 user_account.union_id = union_id
@@ -208,19 +208,26 @@ class UserBaseModel(FrameBaseModel):
                 user_account.login_ip = login_ip
                 user_account.id = user_account_model.add_entity(user_account)
             else:
+                delete_account_cache = False
                 if user_nick and user_account.user_nick != user_nick and is_update_user_nick == True:
                     user_account.user_nick = CryptographyHelper.emoji_to_emoji_base64(user_nick)
                     user_account.user_nick_encrypt = CryptographyHelper.base64_encrypt(user_nick)
+                    delete_account_cache = True
                 if avatar and user_account.avatar != avatar and is_update_user_nick == True:
                     user_account.avatar = avatar
+                    delete_account_cache = True
                 if union_id and user_account.union_id != union_id:
                     user_account.union_id = union_id
-                if mix_nick:
+                    delete_account_cache = True
+                if mix_nick and user_account.mix_nick != mix_nick:
                     user_account.mix_nick = mix_nick
+                    delete_account_cache = True
                 user_account.login_date = now_datetime
                 user_account.login_ip = login_ip
                 user_account_model.update_entity(user_account, "user_nick,user_nick_encrypt,mix_nick,avatar,union_id,login_date,login_ip")
-
+                if delete_account_cache == True:
+                    user_account_model.delete_dependency_key(DependencyKey.user_account(open_id))
+                    
             user_info = user_info_model.get_entity("act_id=%s and open_id=%s", params=[act_id, open_id])
             if not user_info:
                 user_info = UserInfo()
